==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/user/messages/fr/profile.php <==
<?php
return array (
  '%y Years' => '%y ans',
  '<b>This profile stream is still empty!</b>' => '<b>Ce profil est vide.</b>',
  '<b>This profile stream is still empty</b><br>Be the first and post something...' => '<b>Ce profil est vide.</b><br>Soyez le premier à publier quelque chose...',
  '<b>Your profile stream is still empty</b><br>Get started and post something...' => '<b>Votre profil est vide.</b><br>Commencez par publier quelque chose...',
  '<strong>About</strong> this user' => '<strong>À propos</strong> de cet utilisateur',
  '<strong>Profile</strong> menu' => 'Menu <strong>profil</strong>',
  'About' => 'À propos',
  'Allow other selection' => 'Autoriser une autre sélection',
  'Birthday' => 'Date de naissance',
  'Birthday field options' => 'Options de date de naissance',
  'Checkbox' => 'Cocher la case correspondante',
  'Checkbox List' => 'Liste de cases à cocher',
  'Checkbox field options' => 'Options de case à cocher',
  'City' => 'Ville',
  'Comma separated country codes, e.g. DE,EN,AU' => 'Codes pays séparés par des virgules. Par ex : FR,EN,DE',
  'Communication' => 'Communication',
  'Country' => 'Pays',
  'Created at' => 'Créé le',
  'Created by' => 'Créé par',
  'Creation date of the user' => 'Date de création',
  'Date' => 'Date',
  'Date(-time) field options' => 'Options de date et heure',
  'Datetime' => 'Date et heure',
  'Default value' => 'Valeur par défaut',
  'Description' => 'Description',
  'Diverse' => 'Autre',
  'E-Mail' => 'E-Mail',
  'E-mail address of the user' => 'Adresse e-mail de l\'utilisateur',
  'Edit account' => 'Modifier votre compte',
  'Editable' => 'Modifiable',
  'Facebook URL' => 'Lien Facebook',
  'Fax' => 'Fax',
  'Female' => 'Femme',
  'Field Type could not be changed!' => 'Le type de champ ne peut être modifié.',
  'Fieldtype' => 'Type de champ',
  'First name' => 'Prénom',
  'Followers' => 'Abonnés',
  'Following' => 'Abonnements',
  'Friends' => 'Amis',
  'Gender' => 'Genre',
  'General' => 'Général',
  'Hide age per default' => 'Cacher l\'âge par défaut',
  'Hide year in profile' => 'Masquer l\'année dans votre profil',
  'ID' => 'ID',
  'Instagram URL' => 'URL Instagram',
  'Internal Name' => 'Nom interne',
  'Internal name already in use!' => 'Ce nom interne est déjà utilisé.',
  'Internal name could not be changed!' => 'Le nom interne ne peut être modifié.',
  'Invalid field type!' => 'Type de champ invalide.',
  'Invalid!' => 'invalide.',
  'LDAP Attribute' => 'Attributs LDAP',
  'Last login date of the user' => 'Dernière connexion',
  'Last name' => 'Nom',
  'Link Prefix (e.g. https://, mailto:, tel://)' => 'Préfixe du lien (exemples : https://, mailto:, tel://)',
  'LinkedIn URL' => 'Lien LinkedIn',
  'Male' => 'Homme',
  'Markdown' => 'Markdown',
  'Maximum length' => 'Longueur maximale',
  'Maximum value' => 'Valeur maximale',
  'Minimum length' => 'Longueur minimale',
  'Minimum value' => 'Valeur minimale',
  'Mobile' => 'Tel. portable',
  'Module' => 'Module',
  'Must contain at least one character.' => 'Ce champ doit contenir au moins un caractère.',
  'Number' => 'Nombre',
  'Number field options' => 'Options de champ numérique',
  'One option per line. Key=>Value Format (e.g. yes=>Yes)' => 'Une valeur par ligne. Clé=>Valeur (exemple oui=>Oui)',
  'Only alphanumeric characters allowed!' => 'Seuls les caractères alphanumériques sont acceptés.',
  'Other:' => 'Autre:',
  'Phone Private' => 'Tel. privé',
  'Phone Work' => 'Tel. bureau',
  'Please select:' => 'Sélectionnez :',
  'Possible values' => 'Valeurs possibles',
  'Profile Field Category' => 'Catégorie de champ de profil',
  'Regular Expression: Error message' => 'Expression régulière : message d\'erreur',
  'Regular Expression: Validator' => 'Expression régulière : validateur',
  'Required' => 'Requis',
  'Searchable' => 'Interrogeable dans la recherche',
  'Select List' => 'Liste de choix',
  'Select field options' => 'Option de listes',
  'Show at registration' => 'Voir à l\'enregistrement',
  'Show date/time picker' => 'Afficher le calendrier',
  'Social bookmarks' => 'Réseaux sociaux',
  'Sort order' => 'Ordre de tri',
  'Spaces' => 'Espaces',
  'State' => 'Région',
  'Stream' => 'Fil d\'actualités',
  'Street' => 'Rue',
  'Supported ISO3166 country codes' => 'Codes pays au format ISO3166 autorisés',
  'Text' => 'Texte',
  'Text Area' => 'Texte long',
  'Text Field Options' => 'Options de champ de texte',
  'Text area field options' => 'Options de champ de texte long',
  'This profile is no longer available!' => 'Ce profil n\'est plus disponible.',
  'This user account is not approved yet!' => 'Ce compte utilisateur n\'a pas encore été approuvé.',
  'This will add an additional input element for custom values' => 'Ceci va ajouter un nouvel élément de saisie pour les valeurs personnalisées',
  'TikTok URL' => 'URL TikTok',
  'Title' => 'Titre',
  'Translation Category ID' => 'ID de traduction de la catégorie',
  'Twitter URL' => 'Lien Twitter',
  'Type Config' => 'Configuration de type',
  'Updated at' => 'Mis à jour le',
  'Updated by' => 'Mis à jour par',
  'Use as Directory filter' => 'Utiliser comme filtre du répertoire',
  'Username' => 'Identifiant',
  'Validator' => 'Validateur',
  'Vimeo URL' => 'Lien Vimeo',
  'Visible' => 'Visible',
  'Website URL' => 'URL',
  'XMPP Jabber Address' => 'Adresse XMPP/Jabber',
  'Xing URL' => 'Lien Xing',
  'You need to login to view this user profile!' => 'Vous devrez être connecté pour voir ce profil.',
  'YouTube URL' => 'Lien YouTube',
  'Zip' => 'Code postal',
  '{attribute} is required!' => '{attribute} est requis!',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/user/messages/fr/profile.php <==
<?php
return array (
  '%y Years' => '%y ans',
  '<b>This profile stream is still empty!</b>' => '<b>Ce profil est vide.</b>',
  '<b>This profile stream is still empty</b><br>Be the first and post something...' => '<b>Ce profil est vide.</b><br>Soyez le premier à publier quelque chose...',
  '<b>Your profile stream is still empty</b><br>Get started and post something...' => '<b>Votre profil est vide.</b><br>Commencez par publier quelque chose...',
  '<strong>About</strong> this user' => '<strong>À propos</strong> de cet utilisateur',
  '<strong>Profile</strong> menu' => 'Menu <strong>profil</strong>',
  'About' => 'À propos',
  'Allow other selection' => 'Autoriser une autre sélection',
  'Birthday' => 'Date de naissance',
  'Birthday field options' => 'Options de date de naissance',
  'Checkbox' => 'Cocher la case correspondante',
  'Checkbox List' => 'Liste de cases à cocher',
  'Checkbox field options' => 'Options de case à cocher',
  'City' => 'Ville',
  'Comma separated country codes, e.g. DE,EN,AU' => 'Codes pays séparés par des virgules. Par ex : FR,EN,DE',
  'Communication' => 'Communication',
  'Country' => 'Pays',
  'Created at' => 'Créé le',
  'Created by' => 'Créé par',
  'Creation date of the user' => 'Date de création',
  'Date' => 'Date',
  'Date(-time) field options' => 'Options de date et heure',
  'Datetime' => 'Date et heure',
  'Default value' => 'Valeur par défaut',
  'Description' => 'Description',
  'Diverse' => 'Autre',
  'E-Mail' => 'E-Mail',
  'E-mail address of the user' => 'Adresse e-mail de l\'utilisateur',
  'Edit account' => 'Modifier votre compte',
  'Editable' => 'Modifiable',
  'Facebook URL' => 'Lien Facebook',
  'Fax' => 'Fax',
  'Female' => 'Femme',
  'Field Type could not be changed!' => 'Le type de champ ne peut être modifié.',
  'Fieldtype' => 'Type de champ',
  'First name' => 'Prénom',
  'Followers' => 'Abonnés',
  'Following' => 'Abonnements',
  'Friends' => 'Amis',
  'Gender' => 'Genre',
  'General' => 'Général',
  'Hide age per default' => 'Cacher l\'âge par défaut',
  'Hide year in profile' => 'Masquer l\'année dans votre profil',
  'ID' => 'ID',
  'Instagram URL' => 'Lien Instagram',
  'Internal Name' => 'Nom interne',
  'Internal name already in use!' => 'Ce nom interne est déjà utilisé.',
  'Internal name could not be changed!' => 'Le nom interne ne peut être modifié.',
  'Invalid field type!' => 'Type de champ invalide.',
  'Invalid!' => 'invalide.',
  'LDAP Attribute' => 'Attributs LDAP',
  'Last login date of the user' => 'Dernière connexion',
  'Last name' => 'Nom',
  'Link Prefix (e.g. https://, mailto:, tel://)' => 'Préfixe du lien (exemples : https://, mailto:, tel://)',
  'LinkedIn URL' => 'Lien LinkedIn',
  'Male' => 'Homme',
  'Markdown' => 'Markdown',
  'Mastodon URL' => 'Lien Mastodon',
  'Maximum length' => 'Longueur maximale',
  'Maximum value' => 'Valeur maximale',
  'Minimum length' => 'Longueur minimale',
  'Minimum value' => 'Valeur minimale',
  'Mobile' => 'Tel. portable',
  'Module' => 'Module',
  'Must contain at least one character.' => 'Ce champ doit contenir au moins un caractère.',
  'Number' => 'Nombre',
  'Number field options' => 'Options de champ numérique',
  'One option per line. Key=>Value Format (e.g. yes=>Yes)' => 'Une valeur par ligne. Clé=>Valeur (exemple oui=>Oui)',
  'Only alphanumeric characters allowed!' => 'Seuls les caractères alphanumériques sont acceptés.',
  'Other:' => 'Autre:',
  'Phone Private' => 'Tel. privé',
  'Phone Work' => 'Tel. bureau',
  'Please select:' => 'Sélectionnez :',
  'Possible values' => 'Valeurs possibles',
  'Profile Field Category' => 'Catégorie de champ de profil',
  'Regular Expression: Error message' => 'Expression régulière : message d\'erreur',
  'Regular Expression: Validator' => 'Expression régulière : validateur',
  'Required' => 'Requis',
  'Searchable' => 'Interrogeable dans la recherche',
  'Select List' => 'Liste de choix',
  'Select field options' => 'Option de listes',
  'Show at registration' => 'Voir à l\'enregistrement',
  'Show date/time picker' => 'Afficher le calendrier',
  'Social bookmarks' => 'Réseaux sociaux',
  'Sort order' => 'Ordre de tri',
  'Spaces' => 'Espaces',
  'State' => 'Région',
  'Stream' => 'Fil d\'actualités',
  'Street' => 'Rue',
  'Supported ISO3166 country codes' => 'Codes pays au format ISO3166 autorisés',
  'Text' => 'Texte',
  'Text Area' => 'Texte long',
  'Text Field Options' => 'Options de champ de texte',
  'Text area field options' => 'Options de champ de texte long',
  'This profile is no longer available!' => 'Ce profil n\'est plus disponible.',
  'This user account is not approved yet!' => 'Ce compte utilisateur n\'a pas encore été approuvé.',
  'This will add an additional input element for custom values' => 'Ceci va ajouter un nouvel élément de saisie pour les valeurs personnalisées',
  'TikTok URL' => 'Lien TikTok',
  'Title' => 'Titre',
  'Translation Category ID' => 'ID de traduction de la catégorie',
  'Twitter URL' => 'Lien Twitter',
  'Type Config' => 'Configuration de type',
  'Updated at' => 'Mis à jour le',
  'Updated by' => 'Mis à jour par',
  'Use as Directory filter' => 'Utiliser comme filtre du répertoire',
  'Username' => 'Identifiant',
  'Validator' => 'Validateur',
  'Vimeo URL' => 'Lien Vimeo',
  'Visible' => 'Visible',
  'Website URL' => 'Site web',
  'XMPP Jabber Address' => 'Adresse XMPP/Jabber',
  'Xing URL' => 'Lien Xing',
  'You need to login to view this user profile!' => 'Vous devrez être connecté pour voir ce profil.',
  'YouTube URL' => 'Lien YouTube',
  'Zip' => 'Code postal',
  '{attribute} is required!' => '{attribute} est requis!',
);
